@@ -7,7 +7,6 @@
 ## 2010-06-14  added Ndist = 'specified', using D to carry N
 ## 2011-03-27  conditional attachment of rownames (correct bug when N = 0)
 ## 2011-04-06  coastal beta option
-## 2011-10-20  poly argument
 ## 2012-04-10  IHP D may be covariate; more checks
 ## 2012-04-10  MRC
 ## 2013-11-23 IHP for Ndist fixed
@@ -600,19 +599,22 @@ sim.popn <- function (D, core, buffer = 100, model2D = c("poisson",
         ## pre-check details$eps
         if (!is.null(details$saveLambda) && details$saveLambda && 
             model2D %in% c("rLGCP", "rThomas","cluster")) {
-            if (is.null(details$eps)) {
-                if (inherits(core, "mask"))
-                    details$eps <- spacing(core)
-                else 
-                    details$eps <- diff(xl)/64
+          if (is.null(details$eps)) {
+            if (inherits(core, "mask")) {
+              details$eps <- spacing(core)
             }
-            else if (inherits(core, "mask") && details$eps != spacing(core)) {
-                warning ("requested eps for Lambda differs from core mask")
+            else {
+              dx <- diff(range(core$x)) + 2 * buffer
+              details$eps <- dx/64
             }
+          }
+          else if (inherits(core, "mask") && details$eps != spacing(core)) {
+            warning ("requested eps for Lambda differs from core mask")
+          }
         }
         
         if (model2D %in% c("IHP")) {
-            if (!inherits(core, "mask"))
+          if (!inherits(core, "mask"))
                 stop ("for model2D = IHP, core should be a habitat mask")
             # typo fixed 2023-09-17
             if (nsessions>1 && details$movemodel!="static" && 
@@ -900,15 +902,25 @@ sim.popn <- function (D, core, buffer = 100, model2D = c("poisson",
         names(animals) <- c('x','y')
         attr(animals,'covariates') <- NULL
         if (!is.null(covariates)) {
-            tempcov <- list()
-            for (i in 1:length(covariates)) {
-               covi <- sample (names(covariates[[i]]), replace = T, size= nrow(animals),
-                               prob=covariates[[i]])
-               temptxt <- paste ('tempcov$', names(covariates[i]), '<- covi',
-                               sep = '')
-               eval(parse(text=temptxt))
+            if (is.function(covariates) || is.character(covariates)) {
+              if (is.character(covariates)) {
+                covariates <- get(covariates, envir = sys.frame())
+              }
+                # understanding covariates () as the argument, not the secr fn
+                tempcov <- as.data.frame(covariates(animals, ...))
+                attr(animals,'covariates') <- tempcov
+            }
+            else {
+                tempcov <- list()
+                for (i in 1:length(covariates)) {
+                    covi <- sample (names(covariates[[i]]), replace = T, size= nrow(animals),
+                                    prob=covariates[[i]])
+                    temptxt <- paste ('tempcov$', names(covariates[i]), '<- covi',
+                                      sep = '')
+                    eval(parse(text=temptxt))
+                }
+                attr(animals,'covariates') <- as.data.frame(tempcov)
             }
-            attr(animals,'covariates') <- as.data.frame(tempcov)
         }
         if (nrow(animals) > 0)   ## condition added 2011-03-27
             row.names (animals) <- number.from : (nrow(animals)+number.from-1)
